@@ -38,6 +38,8 @@
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/tr/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf doxygen.css )
@@ -52,12 +54,16 @@
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/tr/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/tr/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/tr/common ; rm -rf fdl-license.html )
